# CommanderBot Ext

A collection of cogs and extensions for discord.py bots.

[![package-badge]](https://pypi.python.org/pypi/commanderbot-ext/)
[![version-badge]](https://pypi.python.org/pypi/commanderbot-ext/)

[package-badge]: https://img.shields.io/pypi/v/commanderbot-ext.svg
[version-badge]: https://img.shields.io/pypi/pyversions/commanderbot-ext.svg
